# pymlfs

pymlfs: Machine Learning From Scratch

pymlfs implements classical machine learning models from scratch. Implementations are presented as simply as possible, as the library is designed for educational purposes. 

## Installation

```bash
$ pip install pymlfs
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pymlfs` was created by Youssef Achenchabe. It is licensed under the terms of the MIT license.